@@ -1,11 +1,10 @@
 package Plack::Builder;
 use strict;
-use parent qw( Exporter );
-our @EXPORT = qw( builder add enable enable_if mount );
+use base qw( Exporter );
+our @EXPORT = qw( builder add enable mount );
 
 use Carp ();
 use Plack::App::URLMap;
-use Plack::Middleware::Conditional; # TODO delayed load?
 
 sub new {
     my $class = shift;
@@ -16,26 +15,15 @@ sub add_middleware {
     my($self, $mw, @args) = @_;
 
     if (ref $mw ne 'CODE') {
-        my $mw_class = Plack::Util::load_class($mw, 'Plack::Middleware');
+        my $mw_class = $mw;
+        eval "use $mw_class";
+        die $@ if $@;
         $mw = sub { $mw_class->wrap($_[0], @args) };
     }
 
     push @{$self->{middlewares}}, $mw;
 }
 
-sub add_middleware_if {
-    my($self, $cond, $mw, @args) = @_;
-
-    if (ref $mw ne 'CODE') {
-        my $mw_class = Plack::Util::load_class($mw, 'Plack::Middleware');
-        $mw = sub { $mw_class->wrap($_[0], @args) };
-    }
-
-    push @{$self->{middlewares}}, sub {
-        Plack::Middleware::Conditional->wrap($_[0], condition => $cond, builder => $mw);
-    };
-}
-
 # do you want remove_middleware() etc.?
 
 sub to_app {
@@ -49,14 +37,13 @@ sub to_app {
 }
 
 # DSL goes here
-our $_add = our $_add_if = our $_mount = sub {
+our $_add = our $_mount = sub {
     Carp::croak("enable/mount should be called inside builder {} block");
 };
 
 sub add      { Carp::carp("add is deprecated. Use 'enable'"); $_add->(@_) }
-sub enable         { $_add->(@_) }
-sub enable_if(&$@) { $_add_if->(@_) }
-sub mount          { $_mount->(@_) }
+sub enable   { $_add->(@_) }
+sub mount    { $_mount->(@_) }
 
 sub builder(&) {
     my $block = shift;
@@ -71,9 +58,6 @@ sub builder(&) {
     local $_add = sub {
         $self->add_middleware(@_);
     };
-    local $_add_if = sub {
-        $self->add_middleware_if(@_);
-    };
 
     my $app = $block->();
     $self->to_app($app);
@@ -135,7 +119,7 @@ is syntactically equal to:
   $app = Plack::Middleware::Bar->wrap($app, opt => "val");
   $app = Plack::Middleware::Foo->wrap($app);
 
-In other words, you're supposed to C<add> middleware from outer to inner.
+In other words, you're suposed to C<add> middleware from outer to inner.
 
 =head1 URLMap support
 
