@@ -10,10 +10,8 @@ sub FALSE() { !TRUE }
 sub load_class {
     my($class, $prefix) = @_;
 
-    if ($prefix) {
-        unless ($class =~ s/^\+// || $class =~ /^$prefix/) {
-            $class = "$prefix\::$class";
-        }
+    if ($class !~ s/^\+// && $prefix) {
+        $class = "$prefix\::$class";
     }
 
     my $file = $class;
@@ -26,7 +24,7 @@ sub load_class {
 sub is_real_fh ($) {
     my $fh = shift;
 
-    my $reftype = Scalar::Util::reftype($fh) or return;
+    my $reftype = Scalar::Util::reftype($fh);
     if (   $reftype eq 'IO'
         or $reftype eq 'GLOB' && *{$fh}{IO}
     ) {
@@ -61,8 +59,6 @@ sub set_io_path {
 sub content_length {
     my $body = shift;
 
-    return unless defined $body;
-
     if (ref $body eq 'ARRAY') {
         my $cl = 0;
         for my $chunk (@$body) {
@@ -81,30 +77,22 @@ sub foreach {
 
     if (ref $body eq 'ARRAY') {
         for my $line (@$body) {
-            $cb->($line) if length $line;
+            $cb->($line);
         }
     } else {
-        local $/ = \65536 unless ref $/;
+        local $/ = \4096 unless ref $/;
         while (defined(my $line = $body->getline)) {
-            $cb->($line) if length $line;
+            $cb->($line);
         }
         $body->close;
     }
 }
 
-sub class_to_file {
-    my $class = shift;
-    $class =~ s!::!/!g;
-    $class . ".pm";
-}
-
 sub load_psgi {
-    my $stuff = shift;
+    my $file = shift;
 
-    my $file = $stuff =~ /^[a-zA-Z0-9\_\:]+$/ ? class_to_file($stuff) : $stuff;
     my $app = do $file;
-    return $app->to_app if $app and Scalar::Util::blessed($app) and $app->can('to_app');
-    return $app if $app and (ref $app eq 'CODE' or overload::Method($app, '&{}'));
+    return $app if $app and ref $app eq 'CODE' or overload::Method($app, '&{}');
 
     if (my $e = $@ || $!) {
         die "Can't load $file: $e";
@@ -116,11 +104,14 @@ sub load_psgi {
 sub run_app($$) {
     my($app, $env) = @_;
 
-    return eval { $app->($env) } || do {
+    local $@; my $res = eval { $app->($env) };
+    if ($@) {
         my $body = "Internal Server Error";
         $env->{'psgi.errors'}->print($@);
-        [ 500, [ 'Content-Type' => 'text/plain', 'Content-Length' => length($body) ], [ $body ] ];
-    };
+        return [ 500, [ 'Content-Type' => 'text/plain', 'Content-Length' => length($body) ], [ $body ] ];
+    }
+
+    return $res;
 }
 
 sub headers {
@@ -162,7 +153,6 @@ sub header_set {
     my($set, @new_headers);
     header_iter $headers, sub {
         if (lc $key eq lc $_[0]) {
-            return if $set;
             $_[1] = $val;
             $set++;
         }
@@ -229,11 +219,11 @@ sub can {
 }
 
 sub AUTOLOAD {
-    my $self = shift;
+    my ($self, @args) = @_;
     my $attr = $AUTOLOAD;
     $attr =~ s/.*://;
     if (ref($self->{$attr}) eq 'CODE') {
-        $self->{$attr}->(@_);
+        $self->{$attr}->(@args);
     } else {
         Carp::croak(qq/Can't locate object method "$attr" via package "Plack::Util::Prototype"/);
     }
@@ -242,7 +232,7 @@ sub AUTOLOAD {
 sub DESTROY { }
 
 package Plack::Util::IOWithPath;
-use parent qw(IO::Handle);
+use base qw(IO::Handle);
 
 sub path {
     my $self = shift;
@@ -332,26 +322,11 @@ the binary file, unless otherwise set in the caller's code.
 
 =item load_psgi
 
-  my $app = Plack::Util::load_psgi $psgi_file_or_class;
+  my $app = Plack::Util::load_psgi $app_psgi;
 
-Load C<app.psgi> file or a class name (like C<MyApp::PSGI>) and
-require the file to get PSGI application handler. If the file can't be
-loaded (e.g. file doesn't exist or has a perl syntax error), it will
-throw an exception.
-
-B<Security>: If you give this function a class name or module name
-that is loadable from your system, it will load the module. This could
-lead to a security hole:
-
-  my $psgi = ...; # user-input: consider "Moose.pm"
-  $app = Plack::Util::load_psgi($psgi); # this does 'require "Moose.pm"'!
-
-Generally speaking, passing an external input to this function is
-considered very insecure. But if you really want to do that, be sure
-to validate the argument passed to this function. Also, if you do not
-want to accept an arbitrary class name but only load from a file path,
-make sure that the argument C<$psgi_file_or_class> begins with C</> so
-that Perl's built-in do function won't search the include path.
+Load C<app.psgi> file and evaluate the code to get PSGI application
+handler. If the file can't be loaded (e.g. file doesn't exist or has a
+perl syntax error), it will throw an exception.
 
 =item run_app
 
